# Getting Started with `lumaCLI`

## Prerequisites
Make sure your system is running Python version 3.8 or newer.

## Installation
For a smooth installation of `lumaCLI`, simply execute the following command:

```bash
pip install lumaCLI
```

## Next Steps
Make sure to explore the [Manual](./manual/introduction.md) to familiarize yourself with the extensive API functionalities and commands that `lumaCLI` offers.